{ config, pkgs, inputs, ... }:

{
  imports =
    [ # Include the results of the hardware scan.
      ./hardware-configuration.nix
      inputs.home-manager.nixosModules.default
    ];

  # Bootloader.
  boot.loader.systemd-boot.enable = true;
  boot.loader.efi.canTouchEfiVariables = true;

  networking.hostName = "t0urn3s0l"; # Define your hostname.
  # networking.wireless.enable = true;  # Enables wireless support via wpa_supplicant.

  # Enable Nix Flakes
  nix.settings.experimental-features = ["nix-command" "flakes"];
  
  # Enable Hyprland cache so we don't have to compile it ourselves
  nix.settings = {
    substituters = ["https://hyprland.cachix.org"];
    trusted-public-keys = ["hyprland.cachix.org-1:a7pgxzMz7+chwVL3/pzj6jIBMioiJM7ypFP8PwtkuGc="];
  };

  # Enable networking
  networking.networkmanager.enable = true;

  # Set your time zone.
  time.timeZone = "Europe/Paris";

  # Select internationalisation properties.
  i18n.defaultLocale = "en_GB.UTF-8";

  i18n.extraLocaleSettings = {
    LC_ADDRESS = "fr_FR.UTF-8";
    LC_IDENTIFICATION = "fr_FR.UTF-8";
    LC_MEASUREMENT = "fr_FR.UTF-8";
    LC_MONETARY = "fr_FR.UTF-8";
    LC_NAME = "fr_FR.UTF-8";
    LC_NUMERIC = "fr_FR.UTF-8";
    LC_PAPER = "fr_FR.UTF-8";
    LC_TELEPHONE = "fr_FR.UTF-8";
    LC_TIME = "fr_FR.UTF-8";
  };

  # Enable the X11 windowing system.
  # You can disable this if you're only using the Wayland session.
  services.xserver.enable = false;

  # Enable the KDE Plasma Desktop Environment.
  services.displayManager.sddm.enable = false;
  services.desktopManager.plasma6.enable = false;

  # Configure keymap in X11
  services.xserver.xkb = {
    layout = "fr";
    variant = "";
  };

  programs.hyprland = {
    enable = true;
    xwayland.enable = true;
    # set the flake package
    package = inputs.hyprland.packages.${pkgs.stdenv.hostPlatform.system}.hyprland;
    # make sure to also set the portal package, so that they are in sync
    portalPackage = inputs.hyprland.packages.${pkgs.stdenv.hostPlatform.system}.xdg-desktop-portal-hyprland;
  };

  # Configure console keymap
  console.keyMap = "fr";

  # Enable CUPS to print documents.
  services.printing.enable = true;

  # Enable sound with pipewire.
  hardware.pulseaudio.enable = false;
  security.rtkit.enable = true;
  services.pipewire = {
    enable = true;
    alsa.enable = true;
    alsa.support32Bit = true;
    pulse.enable = true;
    # If you want to use JACK applications, uncomment this
    #jack.enable = true;

    # use the example session manager (no others are packaged yet so this is enabled by default,
    # no need to redefine it in your config for now)
    #media-session.enable = true;
  };

  # Enable touchpad support (enabled default in most desktopManager).
  # services.xserver.libinput.enable = true;

  # Define a user account. Don't forget to set a password with ‘passwd’.
  users.users.zuma = {
    isNormalUser = true;
    description = "zuma";
    shell = pkgs.zsh;
    extraGroups = [ "networkmanager" "wheel" ];
  };

  home-manager = {
    extraSpecialArgs = { inherit inputs; };
    users = {
      "zuma" = import ./home.nix;
    };
  };

  # Enable automatic login for the user.
  services.xserver.displayManager.autoLogin = {
    enable = true;
    user = "zuma";
  };

  services.getty.autologinUser = "zuma";

  environment.sessionVariables = rec {
    XCURSOR_SIZE = 24;
  };

  # Allow unfree packages
  nixpkgs.config.allowUnfree = true;
  nixpkgs.config.permittedInsecurePackages = [
                "cinny-4.2.3"
		"cinny-unwrapped-4.2.3"
              ]; 

  # List packages installed in system profile. To search, run:
  # $ nix search wget
  environment.systemPackages = with pkgs; [
    # GUIs
    gnome-keyring # Keyring for secrets
    seahorse # To edit said secrets
    networkmanagerapplet # To get wifi to work -> Go into wifi connection and select store password for all users
    bitwarden-desktop # For my sweet passwords
    rofi-wayland # Application launcher
    xfce.thunar # GUI Filebrowser
    xfce.xfconf # needed by xfce.thunar
    kitty # Hyprland default terminal
    firefox # Web browser
    cinny-desktop # Matrix Client
    eog # Image viewer (Eye Of Gnome)
    dracula-theme # Dark theme
    dracula-icon-theme # Dark Icon theme
    mpv # Video player
    vlc # Media player a bit more fancy than mpv
    pavucontrol # Volume control
    zotero # For research articles
    gimp # Image Editing
    qbittorrent # Torrent downloader for ... Linux isos.
    evince # PDF viewer 
    gparted # Partitioner tool
    obsidian # PKB and more than that
    waybar # A bar.
    bibata-cursors # Pretty cursors
    kdenlive # Video editing software

    # Shell stuff
    zsh # Favorite shell so far
    starship # Shell prompt that goes fast
    neovim # <3
    git # <3 bis
    btop # HTOP on steroids
    lshw # List all your hardware
    neofetch # To show off
    brightnessctl # To control brightness
    p7zip # For all my zip needs 
    cmatrix # Always need it to show off
    exfat # Needed to format Nikon SD Card
    gptfdisk # Tools for partitioning
    mosh # Mobile shell, great ssh replacement for unstable connection
    ffmpeg # Video and sound editiing
    pywal16 # Generate 16 palette from image
    wev # Utility to find which key you pressed

    # Utilities
    wl-clipboard # Clipboard manager
    swww # Wallpaper engine
    pulseaudio-dlna # To play sound on sound system
  ];

  services.gvfs.enable = true; # Enable Trash so that if I delete my nix files without having saved them I can backup .........
  programs.zsh.enable = true;

  services.tumbler.enable = true; # Thumbnail support
  services.gnome.gnome-keyring.enable = true;
  security.pam.services.hyprland.enableGnomeKeyring = true;

  fonts.packages = with pkgs; [
    nerd-fonts.fira-code
    nerd-fonts.ubuntu
    nerd-fonts.droid-sans-mono
  ];

  # Some programs need SUID wrappers, can be configured further or are
  # started in user sessions.
  # programs.mtr.enable = true;
  # programs.gnupg.agent = {
  #   enable = true;
  #   enableSSHSupport = true;
  # };

  # List services that you want to enable:

  # Enable the OpenSSH daemon.
  # services.openssh.enable = true;
  programs.ssh.startAgent = true;

  # Open ports in the firewall.
  # networking.firewall.allowedTCPPorts = [ ... ];
  # networking.firewall.allowedUDPPorts = [ ... ];
  # Or disable the firewall altogether.
  # networking.firewall.enable = false;

  # This value determines the NixOS release from which the default
  # settings for stateful data, like file locations and database versions
  # on your system were taken. It‘s perfectly fine and recommended to leave
  # this value at the release version of the first install of this system.
  # Before changing this value read the documentation for this option
  # (e.g. man configuration.nix or on https://nixos.org/nixos/options.html).
  system.stateVersion = "24.11"; # Did you read the comment?

}
